Contributing - McCole

Skip to content

# Contributing

Contributions are very welcome. Please file issues or submit pull requests in our GitHub repository. All contributors will be acknowledged, but must abide by our Code of Conduct.

- Setup:
  - `uv venv` (once)
  - `source .venv/bin/activate`
  - `uv sync --extra dev`
- Check package: `make check`
- Build package: `make build`
- Publish package: `twine upload --verbose -u __token__ -p your-pypi-access-token dist/*`
- Build documentation: `make docs`